@@ -1,6 +1,9 @@
 mod cache;
 mod check;
+pub mod checker;
 pub mod fs;
 pub mod linter;
+pub mod logging;
 pub mod message;
 mod parser;
+mod visitor;
