@@ -4,7 +4,8 @@ use anyhow::Result;
 use log::debug;
 use serde::{Deserialize, Serialize};
 
-use crate::check::check_ast;
+use crate::cache::Mode;
+use crate::checker::check_ast;
 use crate::message::Message;
 use crate::{cache, parser};
 
@@ -20,17 +21,24 @@ struct CheckResult {
     messages: Vec<Message>,
 }
 
-pub fn check_path(path: &Path) -> Result<Vec<Message>> {
+pub fn check_path(path: &Path, mode: &Mode) -> Result<Vec<Message>> {
     // Check the cache.
-    if let Some(messages) = cache::get(path) {
+    if let Some(messages) = cache::get(path, mode) {
         debug!("Cache hit for: {}", path.to_string_lossy());
         return Ok(messages);
     }
 
     // Run the linter.
     let python_ast = parser::parse(path)?;
-    let messages = check_ast(path, &python_ast);
-    cache::set(path, &messages);
+    let messages: Vec<Message> = check_ast(&python_ast)
+        .into_iter()
+        .map(|check| Message {
+            kind: check.kind,
+            location: check.location,
+            filename: path.to_string_lossy().to_string(),
+        })
+        .collect();
+    cache::set(path, &messages, mode);
 
     Ok(messages)
 }
